@@ -154,7 +154,7 @@ runBASwebservice_all <- function(handle,
     handle = handle,
     language = language,
     minniAttributeDefinitionName = minniAttributeDefinitionName,
-    rootLevel = transcriptionLevel,
+    rootLevel = NULL,
     verbose = verbose,
     resume = resume,
     params = list(),
