@@ -19,12 +19,12 @@ create_filePairList <- function(ext1Path2rootDir, ext2Path2rootDir, ext1, ext2){
   ext2Path2rootDir = suppressWarnings(normalizePath(ext2Path2rootDir))
   
   # ext1Path2rootDir is valid path
-  if(!file.exists(ext1Path2rootDir)){
+  if(!dir.exists(ext1Path2rootDir)){
     stop('ext1Path2rootDir does not exist!')
   }
   
   # ext2Path2rootDir is valid path
-  if(!file.exists(ext2Path2rootDir)){
+  if(!dir.exists(ext2Path2rootDir)){
     stop('ext2Path2rootDir does not exist!')
   }
   
@@ -34,7 +34,7 @@ create_filePairList <- function(ext1Path2rootDir, ext2Path2rootDir, ext1, ext2){
   
   # get all ext2 file paths
   allExt2FilePaths = list.files(ext2Path2rootDir, pattern=paste(ext2, "$", sep = ""), recursive=T, full.names=T)
-
+  
   # check more ext1 found than ext2
   if(length(allExt1FilePaths) > length(allExt2FilePaths)){
     stop('Found less files with ', ext2, ' extention than files with ', ext1, ' extention')
