@@ -48,7 +48,7 @@
 ##' @param nrOfAllocationRows If this size limit of the data matrix is reached 
 ##' a further \code{nrOfAllocationRows} more rows will be allocated. As this allocation leads to
 ##' a performance penalty one should consider increasing this number for large emuDBs. 
-##' @param resultType Specify class of returned object. Either \code{"emuRtrackdata"} or \code{"trackdata"}.
+##' @param resultType Specify class of returned object. Either \code{"emuRtrackdata"} or \code{"trackdata"} (see \code{\link{trackdata}} and \code{\link{emuRtrackdata}} for details about these objects).
 ##' @param verbose Show progress bars and further information
 ##' @return If the \code{cut} parameter is not set (the default) an object of type \code{\link{trackdata}} or \code{\link{emuRtrackdata}} 
 ##' is returned. If \code{cut} is set and \code{npoints} is not, or the seglist 
@@ -174,12 +174,12 @@
   # check for sample rate consistancy
   uniqSessionBndls =utils::read.table(text = as.character(dplyr::distinct_(seglist, "utts")$utts), sep = ":", 
                                       col.names = c("session", "bundle"), colClasses = c("character", "character"), stringsAsFactors = F)
-  DBI::dbGetQuery(emuDBhandle$connection,"CREATE TEMP TABLE uniq_session_bndls_tmp (session TEXT,bundle TEXT)")
+  DBI::dbExecute(emuDBhandle$connection,"CREATE TEMP TABLE uniq_session_bndls_tmp (session TEXT,bundle TEXT)")
   DBI::dbWriteTable(emuDBhandle$connection, "uniq_session_bndls_tmp", uniqSessionBndls, append = T)
   sesBndls = DBI::dbGetQuery(emuDBhandle$connection, paste0("SELECT bundle.db_uuid, bundle.session, bundle.name, bundle.annotates, bundle.sample_rate, bundle.md5_annot_json ",
                                                             "FROM uniq_session_bndls_tmp, bundle ",
                                                             "WHERE uniq_session_bndls_tmp.session = bundle.session AND uniq_session_bndls_tmp.bundle = bundle.name"))
-  DBI::dbGetQuery(emuDBhandle$connection,"DROP TABLE uniq_session_bndls_tmp")
+  DBI::dbExecute(emuDBhandle$connection,"DROP TABLE uniq_session_bndls_tmp")
   
   # remove uuid & MD5sum because we don't want to scare our users :-)
   sesBndls$db_uuid = NULL
