@@ -386,7 +386,7 @@ write_bpfUtteranceToDb <- function(emuDBhandle,
   queryTxt = paste0("INSERT INTO items VALUES"," ('", emuDBhandle$UUID, "', '", session, "', '", bundle, "', ",
                     utteranceItemID, ", 'bundle', 'ITEM', 1, ", samplerate, ", NULL, NULL, NULL)")
   
-  DBI::dbGetQuery(emuDBhandle$connection, queryTxt)
+  DBI::dbExecute(emuDBhandle$connection, queryTxt)
   
   labelIdxCounter = 1
   
@@ -394,7 +394,7 @@ write_bpfUtteranceToDb <- function(emuDBhandle,
   queryTxt = paste0("INSERT INTO labels VALUES","('", emuDBhandle$UUID, "', '", session, "', '", bundle, "', ",
     utteranceItemID, ", ", labelIdxCounter, ", 'bundle', '')")
   
-  DBI::dbGetQuery(emuDBhandle$connection, queryTxt)
+  DBI::dbExecute(emuDBhandle$connection, queryTxt)
   
   labelIdxCounter = labelIdxCounter + 1
   
@@ -405,7 +405,7 @@ write_bpfUtteranceToDb <- function(emuDBhandle,
     queryTxt = paste0("INSERT INTO labels VALUES","('", emuDBhandle$UUID, "', '", session, "', '", bundle, "', ",
                       utteranceItemID, ", ", labelIdxCounter, ", '", key,"', '", header[[key]], "')")
     
-    DBI::dbGetQuery(emuDBhandle$connection, queryTxt)
+    DBI::dbExecute(emuDBhandle$connection, queryTxt)
     
     labelTracker[[length(labelTracker) + 1L]] = key
     labelIdxCounter = labelIdxCounter + 1
@@ -1054,7 +1054,7 @@ write_bpfItemsLabelsToDb <- function(emuDBhandle,
                         levels[[key]][[idx]][["seqIdx"]], ", ", samplerate, ", ", levels[[key]][[idx]][["point"]], ", ",
                         levels[[key]][[idx]][["start"]], ", ", levels[[key]][[idx]][["duration"]], ")")
       
-      DBI::dbGetQuery(emuDBhandle$connection, queryTxt)
+      DBI::dbExecute(emuDBhandle$connection, queryTxt)
       
       labelIdxCounter = 1
       
@@ -1064,7 +1064,7 @@ write_bpfItemsLabelsToDb <- function(emuDBhandle,
                           "', ", levels[[key]][[idx]][["itemID"]], ", ", labelIdxCounter,", '", 
                           labelKey, "', '", levels[[key]][[idx]][["labels"]][[labelKey]], "')")
         
-        DBI::dbGetQuery(emuDBhandle$connection, queryTxt)
+        DBI::dbExecute(emuDBhandle$connection, queryTxt)
         
         if(!labelKey %in% labelTracker)
         {
@@ -1197,7 +1197,7 @@ write_bpfLinksToDb <- function(emuDBhandle,
                             bundle, "', ", linkIdxMap[[toString(link)]], ", ", 
                             levels[[key]][[idx]][["itemID"]],", NULL)")
           
-          DBI::dbGetQuery(emuDBhandle$connection, queryTxt)
+          DBI::dbExecute(emuDBhandle$connection, queryTxt)
         }
         else if(lower == refLevel)
         {
@@ -1206,7 +1206,7 @@ write_bpfLinksToDb <- function(emuDBhandle,
                              linkIdxMap[[toString(link)]],", NULL)")
           
           
-          DBI::dbGetQuery(emuDBhandle$connection, queryTxt)
+          DBI::dbExecute(emuDBhandle$connection, queryTxt)
         }
       }
     }
@@ -1405,7 +1405,7 @@ unify_bpfLevels <- function(emuDBhandle,
                             ", ", currentLabelIdx, ", '", labelKey, "', '", 
                             levels[[key]][[idx]][["labels"]][[labelKey]], "')")
             
-          DBI::dbGetQuery(emuDBhandle$connection, queryTxt)
+          DBI::dbExecute(emuDBhandle$connection, queryTxt)
           seenLinks[[length(seenLinks) + 1L]] = levels[[key]][[idx]][["links"]][link]
         }
         
